@@ -53,7 +53,7 @@ class Activity(object):
     def extra_activity_data(self):
         '''
         Use this hook to store extra data in activities.
-        If you need to store references to model instances you should use create_model_refeactivity_rence
+        If you need to store references to model instances you should use create_model_reference
 
         eg:
             @property
@@ -74,7 +74,7 @@ class Activity(object):
         '''
         Returns the reference to the object of the activity
         '''
-        raise NotImplementedError('%s must implement activity_object_attr property' % self.__class__.__name__)
+        return self
 
     @property
     def activity_actor_id(self):
